@@ -85,6 +85,10 @@ gconf_editor_window_go_to (GConfEditorWindow *window,
 
 	g_return_if_fail (location != NULL);
 
+	if (!gconf_client_get (gconf_client_get_default (), location, NULL) && 
+	    !gconf_client_dir_exists (gconf_client_get_default (), location, NULL))
+		return;
+
 	child_path = gconf_tree_model_get_tree_path_from_gconf_path (
 				GCONF_TREE_MODEL (window->tree_model), location);
 	if (!child_path)
@@ -658,7 +662,7 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 	if (selection == NULL)
 		gtk_window_set_title (GTK_WINDOW (window), _("GConf editor"));
 	else {
-	  	gchar *name, *title, *path, *escape_path;
+		gchar *name, *title, *path;
 		GtkTreeIter child_iter;
 
 		if (!gtk_tree_selection_get_selected (selection, NULL, &iter)) {
@@ -681,11 +685,8 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 		gtk_statusbar_pop (GTK_STATUSBAR (window->statusbar), 0);
 		gtk_statusbar_push (GTK_STATUSBAR (window->statusbar), 0, path);
 
-		escape_path = gconf_tree_model_get_gconf_escape_path (path);
-		
-		gconf_list_model_set_root_path (GCONF_LIST_MODEL (window->list_model), escape_path);
+		gconf_list_model_set_root_path (GCONF_LIST_MODEL (window->list_model), path);
 
-		g_free (escape_path);
 		g_free (path);
 
 	}
