@@ -51,12 +51,17 @@ struct _GConfEditorWindow {
 	GtkWidget *statusbar;
 
 	GtkItemFactory *popup_factory;
+	GtkItemFactory *item_factory;
 	GtkTreeViewColumn *value_column;
 
+	GtkWidget *non_writable_label;
 	GtkWidget *key_name_label;
 	GtkWidget *short_desc_label;
 	GtkTextBuffer *long_desc_buffer;
 	GtkWidget *owner_label;
+
+	guint tearoffs_notify_id;
+	guint icons_notify_id;
 };
 
 struct _GConfEditorWindowClass {
@@ -66,5 +71,8 @@ struct _GConfEditorWindowClass {
 GType gconf_editor_window_get_type (void);
 GtkWidget *gconf_editor_window_new (void);
 
+void gconf_editor_window_go_to (GConfEditorWindow *window,
+				const char        *location);
+
 #endif /* __GCONF_EDITOR_WINDOW_H__ */
 
