@@ -472,7 +472,7 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (editor->notebook),
 				      FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (editor->notebook), 3);
-	gtk_box_pack_start (GTK_BOX (framebox), editor->notebook, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (framebox), editor->notebook, TRUE, TRUE, 0);
 
 	editor->active_type = EDIT_INTEGER;
 
